/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2005 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.0 of the PHP license,       |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_0.txt.                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Stefan Esser <sesser@hardened-php.net>                       |
  +----------------------------------------------------------------------+
*/

/* $Id: php_sha256.c,v 1.1 2005/11/18 16:42:29 sesser Exp $ */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "ext/standard/info.h"
#include "php_sha256.h"

/* {{{ sha256_module_entry
 */
zend_module_entry sha256_module_entry = {
#if ZEND_MODULE_API_NO >= 20010901
	STANDARD_MODULE_HEADER,
#endif
	"sha256",
	NULL,
	PHP_MINIT(sha256),
	PHP_MSHUTDOWN(sha256),
	PHP_RINIT(sha256),		/* Replace with NULL if there's nothing to do at request start */
	PHP_RSHUTDOWN(sha256),	/* Replace with NULL if there's nothing to do at request end */
	PHP_MINFO(sha256),
#if ZEND_MODULE_API_NO >= 20010901
	"1.0", /* Replace with version number for your extension */
#endif
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_SHA256
ZEND_GET_MODULE(sha256)
#endif

static zend_function_entry new_sha256_function[] =  {
	ZEND_FE(php_sha256,			NULL)
	{ NULL, NULL, NULL }
};

static zend_function_entry new_sha256_file_function[] =  {
	ZEND_FE(php_sha256_file,			NULL)
	{ NULL, NULL, NULL }
};

/* {{{ PHP_MINIT_FUNCTION
 */
PHP_MINIT_FUNCTION(sha256)
{
        int retval = SUCCESS, c=0;
        void *dummy;
        
        if (zend_hash_find(CG(function_table), "sha256", sizeof("sha256"), &dummy)==FAILURE) {
                new_sha256_function[0].fname = "sha256";
#ifdef ZEND_ENGINE_2
                retval = zend_register_functions(NULL, new_sha256_function, CG(function_table), MODULE_PERSISTENT TSRMLS_CC);
#else
                retval = zend_register_functions(new_sha256_function, CG(function_table), MODULE_PERSISTENT TSRMLS_CC);
#endif
                c++;
        }

	if (retval == SUCCESS && zend_hash_find(CG(function_table), "sha256_file", sizeof("sha256_file"), &dummy)==FAILURE) {
                new_sha256_file_function[0].fname = "sha256_file";
#ifdef ZEND_ENGINE_2
                retval = zend_register_functions(NULL, new_sha256_file_function, CG(function_table), MODULE_PERSISTENT TSRMLS_CC);
#else
                retval = zend_register_functions(new_sha256_file_function, CG(function_table), MODULE_PERSISTENT TSRMLS_CC);
#endif
                c++;
        }
        
        if (c == 0) {
                zend_error(E_WARNING, "This version of PHP already has sha256() and sha256_file() builtin, you don't need ext/sha256 anymore.");
        }
        
        return retval;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION
 */
PHP_MSHUTDOWN_FUNCTION(sha256)
{
	return SUCCESS;
}
/* }}} */

/* Remove if there's nothing to do at request start */
/* {{{ PHP_RINIT_FUNCTION
 */
PHP_RINIT_FUNCTION(sha256)
{
	return SUCCESS;
}
/* }}} */

/* Remove if there's nothing to do at request end */
/* {{{ PHP_RSHUTDOWN_FUNCTION
 */
PHP_RSHUTDOWN_FUNCTION(sha256)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION
 */
PHP_MINFO_FUNCTION(sha256)
{
	php_info_print_table_start();
	php_info_print_table_header(2, "sha256 support", "enabled");
	php_info_print_table_end();
}
/* }}} */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
